Error

Enum Error 

pub enum Error {
    SkillNotFound(String),
    InvalidSource(String),
    PathTraversal {
        context: &'static str,
        path: String,
    },
    GitClone {
        url: String,
        message: String,
    },
    Network {
        source: Error,
    },
    Io {
        path: PathBuf,
        source: Error,
    },
    Json {
        source: Error,
    },
    Yaml {
        source: Error,
    },
    AgentUnsupported {
        agent: String,
        operation: &'static str,
    },
    UnknownAgent(String),
    InstallFailed {
        skill: String,
        message: String,
    },
}
The primary error type for all skill operations.

Variants



SkillNotFound(String)

A required skill was not found.



InvalidSource(String)

The provided source string could not be parsed.



PathTraversal

A path traversal attempt was detected in a subpath or skill name.

Fields

context: &'static str

What was being validated (e.g. “subpath”, “skill name”).

path: String

The offending path.



GitClone

Git clone operation failed.

Fields

url: String

The repository URL that failed.

message: String

Error description.



Network

An HTTP request failed.

Fields

source: Error

The underlying reqwest error.



Io

Filesystem I/O error.

Fields

path: PathBuf

The path involved in the operation.

source: Error

The underlying I/O error.



Json

JSON serialization / deserialization error.

Fields

source: Error

The underlying serde_json error.



Yaml

YAML parsing error (frontmatter).

Fields

source: Error

The underlying serde_yml error.



AgentUnsupported

The agent does not support the requested operation.

Fields

agent: String

Agent display name.

operation: &'static str

Operation that is not supported.



UnknownAgent(String)

The specified agent was not found in the registry.



InstallFailed

An installation operation failed.

Fields

skill: String

Skill name.

message: String

Error description.

Implementations

Source

impl Error

pub fn io(path: impl Into<PathBuf>, source: Error) -> Self

Create an I/O error with path context.